# coding: utf-8

# flake8: noqa
"""
    FAIR Evaluator API

    The FAIR Evaluator - automated testing of Web resources for their compliance with the FAIR Metrics  # noqa: E501

    OpenAPI spec version: 0.3.0
    Contact: mark.wilkinson@upm.es
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from fairevaluator.models.collections import Collections
from fairevaluator.models.collections_array import CollectionsArray
from fairevaluator.models.collections_result import CollectionsResult
from fairevaluator.models.error_result import ErrorResult
from fairevaluator.models.errorblock import Errorblock
from fairevaluator.models.evaluate import Evaluate
from fairevaluator.models.evaluation_result import EvaluationResult
from fairevaluator.models.ids import Ids
from fairevaluator.models.metrics import Metrics
from fairevaluator.models.metrics_array import MetricsArray
from fairevaluator.models.metrics_list import MetricsList
from fairevaluator.models.metrics_result import MetricsResult
from fairevaluator.models.search_schema import SearchSchema
from fairevaluator.models.searchinput import Searchinput
from fairevaluator.models.searchresult import Searchresult
