from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from fairevaluator.api.create_a_collection_of_maturity_level_tests_api import CreateACollectionOfMaturityLevelTestsApi
from fairevaluator.api.execute_a_maturity_level_evaluation_api import ExecuteAMaturityLevelEvaluationApi
from fairevaluator.api.register_a_new_maturity_level_test_api import RegisterANewMaturityLevelTestApi
from fairevaluator.api.retrieve_collections_of_maturity_level_tests_api import RetrieveCollectionsOfMaturityLevelTestsApi
from fairevaluator.api.retrieve_a_specific_maturity_test_collection_api import RetrieveASpecificMaturityTestCollectionApi
from fairevaluator.api.retrieve_a_specific_maturity_test_description_api import RetrieveASpecificMaturityTestDescriptionApi
from fairevaluator.api.retrieve_all_known_maturity_level_tests_api import RetrieveAllKnownMaturityLevelTestsApi
from fairevaluator.api.retrieve_an_existing_maturity_level_evaluation_api import RetrieveAnExistingMaturityLevelEvaluationApi
from fairevaluator.api.search_maturity_tests_and_collections_by_keyword_api import SearchMaturityTestsAndCollectionsByKeywordApi
