# coding: utf-8

# flake8: noqa

"""
    FAIR Evaluator API

    The FAIR Evaluator - automated testing of Web resources for their compliance with the FAIR Metrics  # noqa: E501

    OpenAPI spec version: 0.3.0
    Contact: mark.wilkinson@upm.es
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from fairevaluator.api.create_a_collection_of_maturity_level_tests_api import CreateACollectionOfMaturityLevelTestsApi
from fairevaluator.api.execute_a_maturity_level_evaluation_api import ExecuteAMaturityLevelEvaluationApi
from fairevaluator.api.register_a_new_maturity_level_test_api import RegisterANewMaturityLevelTestApi
from fairevaluator.api.retrieve_collections_of_maturity_level_tests_api import RetrieveCollectionsOfMaturityLevelTestsApi
from fairevaluator.api.retrieve_a_specific_maturity_test_collection_api import RetrieveASpecificMaturityTestCollectionApi
from fairevaluator.api.retrieve_a_specific_maturity_test_description_api import RetrieveASpecificMaturityTestDescriptionApi
from fairevaluator.api.retrieve_all_known_maturity_level_tests_api import RetrieveAllKnownMaturityLevelTestsApi
from fairevaluator.api.retrieve_an_existing_maturity_level_evaluation_api import RetrieveAnExistingMaturityLevelEvaluationApi
from fairevaluator.api.search_maturity_tests_and_collections_by_keyword_api import SearchMaturityTestsAndCollectionsByKeywordApi
# import ApiClient
from fairevaluator.api_client import ApiClient
from fairevaluator.configuration import Configuration
# import models into sdk package
from fairevaluator.models.collections import Collections
from fairevaluator.models.collections_array import CollectionsArray
from fairevaluator.models.collections_result import CollectionsResult
from fairevaluator.models.error_result import ErrorResult
from fairevaluator.models.errorblock import Errorblock
from fairevaluator.models.evaluate import Evaluate
from fairevaluator.models.evaluation_result import EvaluationResult
from fairevaluator.models.ids import Ids
from fairevaluator.models.metrics import Metrics
from fairevaluator.models.metrics_array import MetricsArray
from fairevaluator.models.metrics_list import MetricsList
from fairevaluator.models.metrics_result import MetricsResult
from fairevaluator.models.search_schema import SearchSchema
from fairevaluator.models.searchinput import Searchinput
from fairevaluator.models.searchresult import Searchresult
