# coding: utf-8

"""
    FAIR Evaluator API

    The FAIR Evaluator - automated testing of Web resources for their compliance with the FAIR Metrics  # noqa: E501

    OpenAPI spec version: 0.3.0
    Contact: mark.wilkinson@upm.es
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.searchresult import Searchresult  # noqa: E501
from swagger_client.rest import ApiException


class TestSearchresult(unittest.TestCase):
    """Searchresult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchresult(self):
        """Test Searchresult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.searchresult.Searchresult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
