# coding: utf-8

"""
    FAIR Evaluator API

    The FAIR Evaluator - automated testing of Web resources for their compliance with the FAIR Metrics  # noqa: E501

    OpenAPI spec version: 0.3.0
    Contact: mark.wilkinson@upm.es
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from api.retrieve_a_specific_maturity_test_collection_api import RetrieveASpecificMaturityTestCollectionApi  # noqa: E501
from swagger_client.rest import ApiException


class TestRetrieveASpecificMaturityTestCollectionApi(unittest.TestCase):
    """RetrieveASpecificMaturityTestCollectionApi unit test stubs"""

    def setUp(self):
        self.api = api.retrieve_a_specific_maturity_test_collection_api.RetrieveASpecificMaturityTestCollectionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_collections_collectionid_get(self):
        """Test case for collections_collectionid_get

        Retrieve FAIR Metrics Collections by their Evaluator-id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
