# coding: utf-8

"""
    FAIR Evaluator API

    The FAIR Evaluator - automated testing of Web resources for their compliance with the FAIR Metrics  # noqa: E501

    OpenAPI spec version: 0.3.0
    Contact: mark.wilkinson@upm.es
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "fairevaluator"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    author= ["Mark Wilkinson","Mario Prieto", "Pablo Alarcón"],
    version=VERSION,
    url="https://github.com/FAIRMetrics/Metrics",
    description="FAIR Evaluator API",
    author_email="mark.wilkinson@upm.es",
    keywords=["FAIR Evaluator API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    The FAIR Evaluator - automated testing of Web resources for their compliance with the FAIR Metrics  # noqa: E501
    """
)
